.. Cobind documentation master file, created by
   sphinx-quickstart on Dec 23 16:33:43 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

cobind's documentation
=======================


.. toctree::
   :caption: Documentation
   :numbered:
   :maxdepth: 2
   
   introduction
   definition
   installation
   input_format
   dataset
   change_log
   

.. toctree::
   :caption: Usage Information
   :numbered:
   :glob:
   :maxdepth: 2

   usage/cobind.rst
   usage/overlap.rst
   usage/jaccard.rst
   usage/SD.rst
   usage/SS.rst
   usage/PMI.rst
   usage/NPMI.rst
   usage/cooccur.rst
   usage/covary.rst
   usage/SROG.rst
   usage/stat.rst

.. toctree::
   :caption: License

   license

.. toctree::
   :caption: Reference

   reference

